@@ -5,6 +5,7 @@ import yaml
 from ._version import __version__ as version
 from .constants import OutputTypes, default_dependency_file_path
 from .rapids_dependency_file_generator import make_dependency_files
+from .rapids_dependency_file_validator import validate_dependencies
 
 
 def validate_args(argv):
@@ -52,8 +53,8 @@ def generate_matrix(matrix_arg):
         return {}
     matrix = {}
     for matrix_column in matrix_arg.split(";"):
-        kv_pair = matrix_column.split("=")
-        matrix[kv_pair[0]] = [kv_pair[1]]
+        key, val = matrix_column.split("=")
+        matrix[key] = [val]
     return matrix
 
 
@@ -63,6 +64,8 @@ def main(argv=None):
     with open(args.config) as f:
         parsed_config = yaml.load(f, Loader=yaml.FullLoader)
 
+    validate_dependencies(parsed_config)
+
     matrix = generate_matrix(args.matrix)
     to_stdout = all([args.file_key, args.output, args.matrix is not None])
 
